@@ -1,6 +1,6 @@
 package WWW::Google::DistanceMatrix::Result;
 
-$WWW::Google::DistanceMatrix::Result::VERSION   = '0.17';
+$WWW::Google::DistanceMatrix::Result::VERSION   = '0.18';
 $WWW::Google::DistanceMatrix::Result::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ WWW::Google::DistanceMatrix::Result - Placeholder for the result of L<WWW::Googl
 
 =head1 VERSION
 
-Version 0.17
+Version 0.18
 
 =cut
 
@@ -37,7 +37,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/WWW-Google-DistanceMatrix>
+L<https://github.com/manwar/WWW-Google-DistanceMatrix>
 
 =head1 BUGS
 
